@@ -33,13 +33,13 @@ def _attrs_to_mustache(job: Job) -> Dict[str, Union[object, List[Dict[str, objec
     if not job.spec.attributes or not job.spec.attributes._custom_attributes:
         return {}
 
-    r = {}  # type: Dict[str, Union[object, List[Dict[str, object]]]]
+    r: Dict[str, Union[object, List[Dict[str, object]]]] = {}
 
     for k, v in job.spec.attributes._custom_attributes.items():
         ks = k.split('.', maxsplit=1)
         if len(ks) == 2:
             if ks[0] not in r:
-                r[ks[0]] = []  # type[List[Dict[str, object]]
+                r[ks[0]] = []
             cast(List[Dict[str, object]], r[ks[0]]).append({'key': ks[1], 'value': v})
         else:
             r[k] = v
@@ -163,7 +163,7 @@ class BatchSchedulerExecutor(JobExecutor):
     strongly encouraged to restrict the query of job states to the specified jobs in order to reduce
     the load on the queuing system. The output of the status command is then parsed using
     :func:`~parse_status_output` and the status of each job is updated accordingly. If the status
-    of a registered job is not found in the ouput of the queue status command, it is assumed
+    of a registered job is not found in the output of the queue status command, it is assumed
     completed (or failed, depending on its exit code), since most queuing systems automatically
     purge completed jobs from their databases after a short period of time. The exit code is read
     from the exit code file, as described above. If the exit code value is not zero, the job is
@@ -194,9 +194,9 @@ class BatchSchedulerExecutor(JobExecutor):
         """See :func:`~psij.JobExecutor.submit`."""
         logger.info('Job %s: submitting', job.id)
         self._ensure_work_dir()
-        assert (job.spec)
 
-        job.executor = self
+        self._check_job(job)
+
         context = self._create_script_context(job)
 
         # assumes job ids are unique
@@ -206,7 +206,7 @@ class BatchSchedulerExecutor(JobExecutor):
         try:
             logger.debug('Job %s: running submit command', job.id)
             out = self._run_command(self.get_submit_command(job, submit_file_path))
-            logger.debug('Job %s: submit command ouput: %s', job.id, out)
+            logger.debug('Job %s: submit command output: %s', job.id, out)
             job._native_id = self.job_id_from_submit_output(out)
             logger.info('Job %s: native id: %s', job.id, job.native_id)
             self._set_job_status(job, JobStatus(JobState.QUEUED,
@@ -551,7 +551,7 @@ class BatchSchedulerExecutor(JobExecutor):
         Implementations are encouraged to restrict the results to jobs accessible by the current
         user.
         """
-        pass
+        raise NotImplementedError()
 
 
 class _QueuePollThread(Thread):
@@ -563,7 +563,7 @@ class _QueuePollThread(Thread):
         self.config = config
         self.executor = executor
         # native_id -> job
-        self._jobs = {}  # type: Dict[str, List[Job]]
+        self._jobs: Dict[str, List[Job]] = {}
         # counts consecutive errors while invoking qstat or equivalent
         self._poll_error_count = 0
         self._jobs_lock = RLock()
