@@ -1,6 +1,8 @@
 from abc import ABC, abstractmethod
 from typing import Optional, List
 
+from typeguard import check_argument_types
+
 from psij.exceptions import InvalidJobException
 
 
@@ -58,6 +60,8 @@ class ResourceSpecV1(ResourceSpec):
         :param gpu_cores_per_process:
         :param exclusive_node_use:
         """
+        assert check_argument_types()
+
         self.node_count = node_count
         self.process_count = process_count
         self.processes_per_node = processes_per_node
