@@ -14,10 +14,12 @@ if [ "$1" != "--quick" ]; then
 	make web-docs
 
 	mkdir -p web-build/docs
+	echo "Copying docs..."
 	cp -r docs/.web-build/. web-build/docs/
 fi
 
 cp -r web/. web-build/
-cp web/*.css web-build/docs/_static/
+cp web/*.css web-build/docs/
 
 rm -f web-build/*.sh
+rm -f web-build/README
\ No newline at end of file
